@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.          *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #include "kalziumdataobject.h"
@@ -41,7 +41,7 @@ struct StaticKalziumDataObject
     KalziumDataObject kdo;
 };
 
-K_GLOBAL_STATIC( StaticKalziumDataObject, s_kdo )
+K_GLOBAL_STATIC(StaticKalziumDataObject, s_kdo)
 
 KalziumDataObject* KalziumDataObject::instance()
 {
@@ -49,12 +49,12 @@ KalziumDataObject* KalziumDataObject::instance()
 }
 
 KalziumDataObject::KalziumDataObject()
-        : m_search( 0 )
+        : m_search(0)
 {
     // reading elements
     ElementSaxParser * parser = new ElementSaxParser();
 
-    QFile xmlFile( KStandardDirs::locate( "data", "libkdeedu/data/elements.xml" ) );
+    QFile xmlFile(KStandardDirs::locate("data", "libkdeedu/data/elements.xml"));
     QXmlInputSource source(&xmlFile);
     QXmlSimpleReader reader;
 
@@ -69,7 +69,7 @@ KalziumDataObject::KalziumDataObject()
     //read the spectra
     SpectrumParser * spectrumparser = new SpectrumParser();
 
-    QFile xmlSpFile( KStandardDirs::locate( "data", "libkdeedu/data/spectra.xml" ) );
+    QFile xmlSpFile(KStandardDirs::locate("data", "libkdeedu/data/spectra.xml"));
     QXmlInputSource spsource(&xmlSpFile);
     QXmlSimpleReader sp_reader;
 
@@ -84,7 +84,7 @@ KalziumDataObject::KalziumDataObject()
     // reading isotopes
     IsotopeParser * isoparser = new IsotopeParser();
 
-    QFile xmlIsoFile( KStandardDirs::locate( "data", "libkdeedu/data/isotopes.xml" ) );
+    QFile xmlIsoFile(KStandardDirs::locate("data", "libkdeedu/data/isotopes.xml"));
     QXmlInputSource isosource(&xmlIsoFile);
     QXmlSimpleReader isoreader;
 
@@ -96,22 +96,22 @@ KalziumDataObject::KalziumDataObject()
     //we don't need isoparser anymore, let's free its memory
     delete isoparser;
 
-    foreach( Isotope *iso, isotopes )
+    foreach (Isotope *iso, isotopes)
     {
         int num = iso->parentElementNumber();
-        if ( m_isotopes.contains( num ) ) {
-            m_isotopes[num].append( iso );
+        if (m_isotopes.contains(num)) {
+            m_isotopes[num].append(iso);
         } else {
             QList<Isotope*> newlist;
-            newlist.append( iso );
-            m_isotopes.insert( num, newlist );
+            newlist.append(iso);
+            m_isotopes.insert(num, newlist);
         }
     }
 
     // cache it
     m_numOfElements = ElementList.count();
 
-    qAddPostRoutine( KalziumDataObject::cleanup );
+    qAddPostRoutine(KalziumDataObject::cleanup);
 }
 
 KalziumDataObject::~KalziumDataObject()
@@ -123,50 +123,50 @@ KalziumDataObject::~KalziumDataObject()
     QHashIterator<int, QList<Isotope*> > i(m_isotopes);
     while (i.hasNext()) {
         i.next();
-        qDeleteAll( i.value());
+        qDeleteAll(i.value());
     }
-    
+
     //Delete the spectra
     qDeleteAll(m_spectra);
 }
 
-Element* KalziumDataObject::element( int number )
+Element* KalziumDataObject::element(int number)
 {
     // checking that we are requesting a valid element
-    if ( ( number <= 0 ) || ( number > m_numOfElements ) )
+    if ((number <= 0) || (number > m_numOfElements))
         return 0;
     return ElementList[ number-1 ];
 }
 
-QString KalziumDataObject::unitAsString( const int unit ) const
+QString KalziumDataObject::unitAsString(const int unit) const
 {
-    return KUnitConversion::Converter().unit( unit ).data()->symbol();
+    return KUnitConversion::Converter().unit(unit).data()->symbol();
 }
 
-QPixmap KalziumDataObject::pixmap( int number )
+QPixmap KalziumDataObject::pixmap(int number)
 {
     // checking that we are requesting a valid element
-    if ( ( number <= 0 ) || ( number > m_numOfElements ) )
+    if ((number <= 0) || (number > m_numOfElements))
         return 0;
-    if ( PixmapList.isEmpty() )
+    if (PixmapList.isEmpty())
         loadIconSet();
     return PixmapList[ number-1 ];
 }
 
-QList<Isotope*> KalziumDataObject::isotopes( Element * element )
+QList<Isotope*> KalziumDataObject::isotopes(Element * element)
 {
-    return isotopes( element->dataAsVariant( ChemicalDataObject::atomicNumber ).toInt() );
+    return isotopes(element->dataAsVariant(ChemicalDataObject::atomicNumber).toInt());
 }
 
-QList<Isotope*> KalziumDataObject::isotopes( int number )
+QList<Isotope*> KalziumDataObject::isotopes(int number)
 {
-    return m_isotopes.contains( number ) ? m_isotopes.value( number ) : QList<Isotope*>();
+    return m_isotopes.contains(number) ? m_isotopes.value(number) : QList<Isotope*>();
 }
 
-Spectrum * KalziumDataObject::spectrum( int number )
+Spectrum * KalziumDataObject::spectrum(int number)
 {
-    foreach (Spectrum * s, m_spectra ) {
-        if (s->parentElementNumber() == number ) {
+    foreach (Spectrum * s, m_spectra) {
+        if (s->parentElementNumber() == number) {
             return s;
         }
     }
@@ -175,7 +175,7 @@ Spectrum * KalziumDataObject::spectrum( int number )
 }
 
 
-void KalziumDataObject::setSearch( Search *srch )
+void KalziumDataObject::setSearch(Search *srch)
 {
     m_search = srch;
 }
@@ -196,21 +196,21 @@ void KalziumDataObject::loadIconSet()
     //FIXME in case we ever get more than one theme we need
     //a settings-dialog where we can select the different iconsets...
     const QString setname = "school";
-    const QString pathname = KGlobal::dirs()->findResourceDir( "appdata", "data/iconsets/" ) + "data/iconsets/";
+    const QString pathname = KGlobal::dirs()->findResourceDir("appdata", "data/iconsets/") + "data/iconsets/";
 
-    for ( int i = 0 ; i < m_numOfElements ; i++ )
+    for (int i = 0; i < m_numOfElements; ++i)
     {
-        QString filename = pathname + setname + '/' + QString::number( i+1 ) + ".svg";
+        QString filename = pathname + setname + '/' + QString::number(i + 1) + ".svg";
 
-        QPixmap pix = cache.loadFromSvg( filename, QSize( 40, 40 ) );
-        if ( pix.isNull() ) {
-            pix = QPixmap( 40, 40 );
+        QPixmap pix = cache.loadFromSvg(filename, QSize(40, 40));
+        if (pix.isNull()) {
+            pix = QPixmap(40, 40);
             pix.fill(Qt::transparent);
 
-            QPainter p( &pix );
+            QPainter p(&pix);
             Element *e =  ElementList.at(i);
-            QString esymbol = e->dataAsString( ChemicalDataObject::symbol );
-            p.drawText(0,0,40,40, Qt::AlignCenter | Qt::TextWordWrap, esymbol );
+            QString esymbol = e->dataAsString(ChemicalDataObject::symbol);
+            p.drawText(0,0,40,40, Qt::AlignCenter | Qt::TextWordWrap, esymbol);
             p.end();
         }
         PixmapList << pix;
